@@ -11,6 +11,9 @@
  *   not to make any modifications and use it as it stands.
  *
  * $Log: hci.h,v $
+ * Revision 1.12  2004/09/06 04:00:31  schwitrs
+ * added HCI_BUSY entry
+ *
  * Revision 1.11  2004/03/06 18:18:19  schwitrs
  * added HCI_LCD_BRIGHTNESS def
  *
@@ -162,6 +165,7 @@ enum {
 	    HCI_SIMULTANEOUS    = 0x0103,
 	    HCI_TVOUT           = 0x0104,
 	    //	    HCI_BUSY            = 0x01,
+	    HCI_BUSY            = 0x40,
 };
 enum {
   HCI_FAN_LOW        = 0x0080, //1000 0000
