@@ -7,6 +7,21 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <sys/ioctl.h>
+#include <stdlib.h>
+
+int accessMode=ACCESS_DIRECT;
+
+void
+detAccessMode()
+{
+ accessMode=ACCESS_DIRECT;
+ if ( 0==access(TOSH_PROC, R_OK) )
+   accessMode=ACCESS_KERNEL;
+ else if ( 0==access("/proc/acpi",R_OK) ) {
+   fprintf(stderr,"required kernel toshiba support not enabled.\n");
+   exit(1);
+ }
+} /* detAccessMode */
 
 #ifdef USE_KERNEL_INTERFACE
 int 
