@@ -3,6 +3,7 @@
 
 static ToshibaID idList[] = {
   {0xfc00  ,"Satellite 2140CDS"},
+  {0xfc01  ,"Satellite 2670/2675/2715XDVD"},
   {0xfc02  ,"Satellite Pro 4290"},
   {0xfc04  ,"Portege 3440CT"},
   {0xfc08  ,"Satellite 2100CDS/CDT"},
@@ -14,7 +15,7 @@ static ToshibaID idList[] = {
   {0xfc10  ,"Satellite 2550/2590"},
   {0xfc11  ,"Portage 3110CT"},
   {0xfc12  ,"Portage 3300CT"},
-  {0xfc13  ,"Portage 7020CT"},
+  {0xfc13  ,"Portege 7020CT"},
   {0xfc15  ,"Satellite 4030/4030X/4050/4060/4070/4080/4090/4100X CDS/CDT"},
   {0xfc17  ,"Satellite 2545X/2520/2540 CDS/CDT"},
   {0xfc18  ,"Satellite 4000/4010 XCDT"},
@@ -29,8 +30,8 @@ static ToshibaID idList[] = {
   {0xfc45  ,"T4400SX/SXC"},
   {0xfc51  ,"Satellite S2210CDT"},
   {0xfc52  ,"2770 dvd"},
-  {0xfc53  ,"Portege 7220"},
-  {0xfc54  ,"Libretto 50CT ???????"},
+  {0xfc53  ,"Portege 7200/7220"},
+  {0xfc54  ,"Libretto 50CT, Satellite 2805-S401"},
   {0xfc56  ,"Portege 3480CT"},
   {0xfc57  ,"Satellite 2250XCDS"},
   {0xfc5a  ,"Satellite Pro 4600"},
@@ -46,13 +47,15 @@ static ToshibaID idList[] = {
   {0xfc6d  ,"T1850C"},
   {0xfc6e  ,"T1850"},
   {0xfc6f  ,"T1800"},
+  {0xfc70  ,"Libretto L2"},
   {0xfc71  ,"Satellite Pro 6000"},
   {0xfc72  ,"Satellite 1805-S207/S274, 1800-712/814"},
   {0xfc73  ,"Portege 2000"},
   {0xfc77  ,"Satellite 5005-S507"},
   {0xfc78  ,"Tecra 9100"},
   {0xfc79  ,"Satellite TE2000"},
-  {0xfc7a  ,"Satellite 5100-201"},
+  {0xfc7a  ,"Satellite 5100-201,5105-S607"},
+  {0xfc7b  ,"Portege 4010"},
   {0xfc7d  ,"satellite pro 6100"},
   {0xfc7e  ,"T4600C"},
   {0xfc7f  ,"T4600"},
@@ -62,6 +65,7 @@ static ToshibaID idList[] = {
   {0xfc86  ,"Satellite TE2100"},
   {0xfc91  ,"T2400CT"},
   {0xfc97  ,"T4800CT"},
+  {0xfc98  ,"T1910"},
   {0xfc99  ,"T4700CS"},
   {0xfc9b  ,"T4700CT"},
   {0xfc9d  ,"T1950"},
@@ -70,11 +74,13 @@ static ToshibaID idList[] = {
   {0xfca1  ,"Satellite 2400-103, 1405-s171"},
   {0xfca3  ,"Satellite 1405-S151, 1400-103, 1400-503"},
   {0xfca5  ,"Satellite 5100-503, 5105-S901"},
+  {0xfca7  ,"DynaBook SS S5"},
   {0xfca8  ,"Satellite 5200-*, 5205-*"},
   {0xfca9  ,"Satellite 2410-*, 1410-604, 1415-S173"},
   {0xfcac  ,"Portege 3505"},
   {0xfcb0  ,"Satellite Pro M10, M15-S405"},
   {0xfcba  ,"T2150"},
+  {0xfcb5  ,"T2130CT"},
   {0xfcbe  ,"T4850CT"},
   {0xfcc0  ,"Satellite Pro 420x"},
   {0xfcc1  ,"Satellite 100x"},
@@ -118,7 +124,7 @@ static ToshibaID idList[] = {
   {0xfcf6  ,"R100"},
   {0xfcf7  ,"Satellite A10-213"},
   {0xfcf8  ,"Satellite A10, A20, A25-S207"},
-  {0xfcff  ,"Portege M100"},
+  {0xfcff  ,"Portege M100/M300 Tecra M2/A2/A3"},
   {0       ,"" } 
 };
 
