@@ -20,7 +20,7 @@
  *
  */
 
-static char const rcsid[]="$Id: toshset.cc,v 1.34 2004/03/06 18:17:37 schwitrs Exp $";
+static char const rcsid[]="$Id: toshset.cc,v 1.41 2005/06/25 19:57:40 schwitrs Exp $";
 static char const rcsversion[]="$State: Exp $";
 
 
@@ -54,6 +54,7 @@ static char const rcsversion[]="$State: Exp $";
 #include<sys/perm.h>
 #endif
 
+#include "kernelInterface.h"
 #include "sci.h"
 #include "hci.h"
 #include "toshibaIDs.hh"
@@ -68,6 +69,7 @@ static int id;
 static char versionString[80];
 static int  verbose=0;
 static int  longQuery=0;
+static int  fast=0;
 
 
 
@@ -125,6 +127,17 @@ struct VersionFeature : public Feature {
   virtual const char* error(int) const {return "";}
 };
 
+struct AccessFeature : public Feature {
+  AccessFeature() :
+    Feature("HCI/SCI access") {}
+  virtual ~AccessFeature() {}
+  virtual int action(const char**) const {return 1;}
+  virtual int query(OStringStream &os) const {
+   os << "HCI/SCI access mode: " 
+      << (accessMode==ACCESS_DIRECT?"direct":"kernel") << ends; return 0;}
+  virtual const char* error(int) const {return "";}
+};
+
 struct ModelFeature : public Feature {
   int id;
   ModelFeature(int id) :
@@ -681,7 +694,13 @@ HciFeature::query(OStringStream& os) const
  reg.ecx = 0;
  reg.edx = 0;
  int ret=0;
- ret = HciFunction( &reg );
+ int retries=3;
+ while ( --retries ) {
+   ret = HciFunction( &reg );
+   if ( ret != HCI_BUSY ) 
+     break;
+ }
+   
  // reg.ecx &= ~0x0080;  //this is some sort of status bit
  if ( ret == HCI_SUCCESS ) {
    for (int i=0 ; i<values.size() ; i++)
@@ -1030,10 +1049,12 @@ struct LbaFeature : public HciFeature {
    if ((*s)[0]=='0' &&
        tolower((*s)[1])=='x') {
      IStringStream is( (*s)+2 );
-     is >> hex >> reg.ecx;
+     long tmp = reg.ecx;
+     is >> hex >> tmp;
    } else {
      IStringStream is( *s );
-     is >> reg.ecx;
+     long tmp = reg.ecx;
+     is >> tmp;
    }
    cout << "setting lba to " << reg.ecx << '\n';
    int ret = HciFunction( &reg );
@@ -1076,10 +1097,12 @@ struct HibInfoFeature : public HciFeature {
    if ((*s)[0]=='0' &&
 	 tolower((*s)[1])=='x') {
      IStringStream is( (*s)+2 );
-     is >> hex >> reg.ecx;
+     long tmp = reg.ecx;
+     is >> hex >> tmp;
    } else {
      IStringStream is( *s );
-     is >> reg.ecx;
+     long tmp = reg.ecx;
+     is >> tmp;
    }
    String type = "invalid";
    switch (hibInfoMode) {
@@ -1141,6 +1164,7 @@ OwnerStringFeature::action(const char **s) const
    cerr << "string too long\n";
    return 0;
  }
+ int allowedFailures=30;
  for (int i=0 ; i<512 ; i+=4) {
    reg.eax = HCI_SET;
    reg.ebx = HCI_OWNERSTRING;
@@ -1160,6 +1184,13 @@ OwnerStringFeature::action(const char **s) const
    //   cout << "edx: " << hex << reg.edx << dec << '\n';
    int ret = HciFunction(&reg);
    if ( ret != HCI_SUCCESS ) {
+     allowedFailures--;
+     if ( allowedFailures<=0 ) {
+       cerr << "too many HCI errors setting feature " << name << '\n'
+	    << "\tHciFunction returned " << error(ret) 
+	    << " for i= " << i << '\n';
+       return 0;
+     }
      i -= 4;
      p -= 4;
    }
@@ -1399,11 +1430,12 @@ public:
        //cout << "arg[" << j << "]: " << p[j] << ' ' << strlen(p[j]) << '\n';
      }
      feature->action( p ); 
-     OStringStream os; 
-     feature->query(os); 
-     os << ends;
-     //if ( os.rdbuf()->pcount() )
-     cout << os.rdbuf() << '\n'; 
+     if ( !fast ) {
+       OStringStream os; 
+       feature->query(os); 
+       os << ends;
+       cout << os.rdbuf() << '\n'; 
+     }
     }
   const char* name() const { return feature->name; }
 };
@@ -1495,12 +1527,10 @@ main(      int   argc,
    return 1;
  }
 
- /* do some quick checks on the laptop */
+ // should be use /dev/toshiba or direct calls to the BIOS
+ detAccessMode();
 
- if (SciSupportCheck(&version)==1) {
-   cerr << argv[0] << ": this computer is not supported" << endl;
-   return 1;
- }
+ /* do some quick checks on the laptop */ 
 
  bios = HciGetBiosVersion();
  if (bios==0) {
@@ -1550,6 +1580,7 @@ main(      int   argc,
 
  ToggleFeature verboseFeature(verbose,"verbose");
  ToggleFeature longFeature(longQuery,"long query");
+ ToggleFeature fastFeature(fast,"run fast");
 
  VersionFeature versionFeature;
  features.append(&versionFeature);
@@ -1557,6 +1588,9 @@ main(      int   argc,
  ModelFeature modelFeature(id);
  features.append(&modelFeature);
 
+ AccessFeature accessFeature;
+ features.append(&accessFeature);
+
  SciFeature batteryFeature(SCI_BATTERY_SAVE,"battery save mode");
  batteryFeature.addValue( "user"   , SCI_USER_SETTINGS , "user settings");
  batteryFeature.addValue( "full"   , SCI_FULL_POWER    , "full power");
@@ -1612,6 +1646,31 @@ main(      int   argc,
 // firFeature.addValue( "off"  , HCI_DISABLE   , "off" );
 // features.append(&firFeature);
 
+ SciFeature legacyUSBFeature(SCI_USB_LEGACY_MODE, "USB legacy mode");
+ legacyUSBFeature.addValue("disable" , SCI_DISABLED , "disabled");
+ legacyUSBFeature.addValue("enable"  , SCI_ENABLED , "enabled");
+ features.append(&legacyUSBFeature);
+
+ SciFeature USBFDDFeature(SCI_USB_FDD_EMULAT, "USB FDD emulation mode");
+ USBFDDFeature.addValue("disable" , SCI_DISABLED , "disabled");
+ USBFDDFeature.addValue("enable"  , SCI_ENABLED , "enabled");
+ features.append(&USBFDDFeature);
+
+ SciFeature LANcontrollerFeature(SCI_LAN_CONTROLLER, "LAN controller");
+ LANcontrollerFeature.addValue("disable" , SCI_DISABLED , "disabled");
+ LANcontrollerFeature.addValue("enable"  , SCI_ENABLED , "enabled");
+ features.append(&LANcontrollerFeature);
+
+ SciFeature soundlogoFeature(SCI_SOUND_LOGO, "sound logo");
+ soundlogoFeature.addValue("disable" , SCI_DISABLED , "disabled");
+ soundlogoFeature.addValue("enable"  , SCI_ENABLED , "enabled");
+ features.append(&soundlogoFeature);
+
+ SciFeature startuplogoFeature(SCI_STARTUP_LOGO, "startup logo");
+ startuplogoFeature.addValue("picture" , SCI_PICTURE_LOGO , "picture");
+ startuplogoFeature.addValue("animation"  , SCI_ANIMATION_LOGO , "animation");
+ features.append(&startuplogoFeature);
+
  HciFeature videoFeature(HCI_VIDEO_OUT,"Video out");
  videoFeature.addValue("int" ,HCI_INTERNAL , "internal: LCD" );
  videoFeature.addValue("ext" ,HCI_EXTERNAL , "external monitor" );
@@ -1875,11 +1934,17 @@ main(      int   argc,
 		 &autoOffFeature),
    new ArgSet<1>("-bluetooth","<on|off> enable/disable internal bluetooth",
 		 &blueToothFeature),
+   new ArgSet<1>("-usblegacy","<enable|disable> USB legacy mode",&legacyUSBFeature),
+   new ArgSet<1>("-usbfdd","<enable|disable> USB FDD emulation mode",&USBFDDFeature),
+   new ArgSet<1>("-lan","<enable|disable> LAN controller",&LANcontrollerFeature),
+   new ArgSet<1>("-soundlogo","<enable|disable> sound logo",&soundlogoFeature),
+   new ArgSet<1>("-startlogo","<picture|animation> startup logo mode",&soundlogoFeature),
    new ArgQuery("-q",
 		"[glob] query option matching glob (or all if no arg)",
 		features,argList),
    new ArgSet<0>("-v","toggle verbose mode",&verboseFeature),
    new ArgSet<0>("-l","toggle long query",&longFeature),
+   new ArgSet<0>("-fast","skip checks, run faster",&fastFeature),
    0 };
 
  CmdLineArgs args( argv[0], argList );
@@ -1891,6 +1956,12 @@ main(      int   argc,
    if ( !args.process(argc,argv) )
      return 1;
 
+ if ( !fast )
+   if (SciSupportCheck(&version)==1) {
+     cerr << argv[0] << ": this computer is not supported" << endl;
+     return 1;
+   }
+
  SciCloseInterface();
 
  return 0;
